@@ -5,11 +5,9 @@
             Binary(int value);
 
             Binary &operator+=(Binary const &other);
-    };
 
-    Binary operator+(Binary const &lhs, Binary const &rhs)
-    {
-        Binary tmp(lhs);
-        tmp += rhs;
-        return tmp;
-    }
+        private:
+            void add(Binary const &other);
+
+        friend Binary operator+(Binary const &lhs, Binary const &rhs);
+    };
