@@ -11,17 +11,17 @@
             std::ostream &operator()(std::ostream &ostr) const;
     };
 
-        Align::Align(unsigned width, std::ios::fmtflags alignment)
-        :
-            d_width(width),
-            d_alignment(alignment)
-        {}
+    Align::Align(unsigned width, std::ios::fmtflags alignment)
+    :
+        d_width(width),
+        d_alignment(alignment)
+    {}
 
-        std::ostream &Align::operator()(std::ostream &ostr) const
-        {
-            ostr.setf(d_alignment, std::ios::adjustfield);
-            return ostr << std::setw(d_width);
-        }
+    std::ostream &Align::operator()(std::ostream &ostr) const
+    {
+        ostr.setf(d_alignment, std::ios::adjustfield);
+        return ostr << std::setw(d_width);
+    }
 
     std::ostream &operator<<(std::ostream &ostr, Align const &align)
     {
@@ -33,8 +33,8 @@
     int main()
     {
         cout
-            << "`" << Align(5, ios::left) << "hi" << "'"
-            << "`" << Align(10, ios::right) << "there" << "'\n";
+            << "`" << Align{ 5, ios::left } << "hi" << "'"
+            << "`" << Align{ 10, ios::right } << "there" << "'\n";
     }
 
     /*
